|Build Status|

|PyPI version|

|Coverage Status|

EvoDAG
======

Evolving Directed Acyclic Graph (EvoDAG) is a steady-state Genetic
Programming system with tournament selection. The main characteristic of
EvoDAG is that the genetic operation is performed at the root. EvoDAG
was inspired by the geometric semantic crossover proposed by `Alberto
Moraglio <https://scholar.google.com.mx/citations?user=0y4XRI0AAAAJ&hl=en&oi=ao>`__
*et al.* and the implementation performed by `Leonardo
Vanneschi <https://scholar.google.com.mx/citations?user=uR5K07QAAAAJ&hl=en&oi=ao>`__
*et al*.

Install EvoDAG
--------------

-  Install using pip
   ``pip install EvoDAG``

Using the source code
~~~~~~~~~~~~~~~~~~~~~

-  Clone the repository
   ``git clone  https://github.com/mgraffg/EvoDAG.git``
-  Install the package as usual
   ``python setup.py install``
-  To install only for the use then
   ``python setup.py install --user``

.. |Build Status| image:: https://travis-ci.org/mgraffg/EvoDAG.svg?branch=master
   :target: https://travis-ci.org/mgraffg/EvoDAG
.. |PyPI version| image:: https://badge.fury.io/py/EvoDAG.svg
   :target: https://badge.fury.io/py/EvoDAG
.. |Coverage Status| image:: https://coveralls.io/repos/github/mgraffg/EvoDAG/badge.svg?branch=master
   :target: https://coveralls.io/github/mgraffg/EvoDAG?branch=master
